package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.AiComputingInstances;

/**
 * AI算力服务Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IAiComputingInstancesService 
{
    /**
     * 查询AI算力服务
     * 
     * @param id AI算力服务主键
     * @return AI算力服务
     */
    public AiComputingInstances selectAiComputingInstancesById(Integer id);

    /**
     * 查询AI算力服务列表
     * 
     * @param aiComputingInstances AI算力服务
     * @return AI算力服务集合
     */
    public List<AiComputingInstances> selectAiComputingInstancesList(AiComputingInstances aiComputingInstances);

    /**
     * 新增AI算力服务
     * 
     * @param aiComputingInstances AI算力服务
     * @return 结果
     */
    public int insertAiComputingInstances(AiComputingInstances aiComputingInstances);

    /**
     * 修改AI算力服务
     * 
     * @param aiComputingInstances AI算力服务
     * @return 结果
     */
    public int updateAiComputingInstances(AiComputingInstances aiComputingInstances);

    /**
     * 批量删除AI算力服务
     * 
     * @param ids 需要删除的AI算力服务主键集合
     * @return 结果
     */
    public int deleteAiComputingInstancesByIds(Integer[] ids);

    /**
     * 删除AI算力服务信息
     * 
     * @param id AI算力服务主键
     * @return 结果
     */
    public int deleteAiComputingInstancesById(Integer id);
}
