package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.AiComputingInstances;
import com.zyc.system.service.IAiComputingInstancesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * AI算力服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/AiComputingInstancesController")
public class AiComputingInstancesController extends BaseController
{
    @Autowired
    private IAiComputingInstancesService aiComputingInstancesService;

    /**
     * 查询AI算力服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:instances:list')")
    @GetMapping("/list")
    public TableDataInfo list(AiComputingInstances aiComputingInstances)
    {
        startPage();
        List<AiComputingInstances> list = aiComputingInstancesService.selectAiComputingInstancesList(aiComputingInstances);
        return getDataTable(list);
    }

    /**
     * 导出AI算力服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:instances:export')")
    @Log(title = "AI算力服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AiComputingInstances aiComputingInstances)
    {
        List<AiComputingInstances> list = aiComputingInstancesService.selectAiComputingInstancesList(aiComputingInstances);
        ExcelUtil<AiComputingInstances> util = new ExcelUtil<AiComputingInstances>(AiComputingInstances.class);
        util.exportExcel(response, list, "AI算力服务数据");
    }

    /**
     * 获取AI算力服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:instances:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(aiComputingInstancesService.selectAiComputingInstancesById(id));
    }

    /**
     * 新增AI算力服务
     */
    @PreAuthorize("@ss.hasPermi('system:instances:add')")
    @Log(title = "AI算力服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AiComputingInstances aiComputingInstances)
    {
        return toAjax(aiComputingInstancesService.insertAiComputingInstances(aiComputingInstances));
    }

    /**
     * 修改AI算力服务
     */
    @PreAuthorize("@ss.hasPermi('system:instances:edit')")
    @Log(title = "AI算力服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AiComputingInstances aiComputingInstances)
    {
        return toAjax(aiComputingInstancesService.updateAiComputingInstances(aiComputingInstances));
    }

    /**
     * 删除AI算力服务
     */
    @PreAuthorize("@ss.hasPermi('system:instances:remove')")
    @Log(title = "AI算力服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(aiComputingInstancesService.deleteAiComputingInstancesByIds(ids));
    }
}
